@@ -6,7 +6,7 @@
 # SPDX-License-Identifier: LGPL-3.0-only
 #
 
-"""RestFull API interface class."""
+"""RestFul API interface class."""
 
 import os
 import socket
@@ -18,9 +18,10 @@ from urllib.parse import urljoin
 
 from glances import __apiversion__, __version__
 from glances.events_list import glances_events
-from glances.globals import json_dumps, weak_lru_cache
+from glances.globals import json_dumps
 from glances.logger import logger
 from glances.password import GlancesPassword
+from glances.plugins.plugin.dag import get_plugin_dependencies
 from glances.processes import glances_processes
 from glances.servers_list import GlancesServersList
 from glances.servers_list_dynamic import GlancesAutoDiscoverClient
@@ -183,10 +184,12 @@ class GlancesRestfulApi:
                 self.url_prefix = self.url_prefix.rstrip('/')
             logger.debug(f'URL prefix: {self.url_prefix}')
 
-    def __update_stats(self):
+    def __update_stats(self, plugins_list_to_update=None):
         # Never update more than 1 time per cached_time
-        if self.timer.finished():
-            self.stats.update()
+        # Also update if specific plugins are requested
+        # In  this case, lru_cache will handle the stat's update frequency
+        if self.timer.finished() or plugins_list_to_update:
+            self.stats.update(plugins_list_to_update=plugins_list_to_update)
             self.timer = Timer(self.args.cached_time)
 
     def __update_servers_list(self):
@@ -436,7 +439,8 @@ class GlancesRestfulApi:
             HTTP/1.1 404 Not Found
         """
         # Update the stat
-        self.__update_stats()
+        # TODO: Why ??? Try to comment it
+        # self.__update_stats()
 
         try:
             plist = self.plugins_list
@@ -456,7 +460,7 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(self.servers_list.get_servers_list() if self.servers_list else [])
 
-    @weak_lru_cache(maxsize=1, ttl=1)
+    # Comment this solve an issue on Home Assistant See #3238
     def _api_all(self):
         """Glances API RESTful implementation.
 
@@ -485,7 +489,6 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(statval)
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_all_limits(self):
         """Glances API RESTful implementation.
 
@@ -502,7 +505,6 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(limits)
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_all_views(self):
         """Glances API RESTful implementation.
 
@@ -519,7 +521,6 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(limits)
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api(self, plugin: str):
         """Glances API RESTful implementation.
 
@@ -531,7 +532,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat ID
@@ -549,7 +550,6 @@ class GlancesRestfulApi:
             status.HTTP_400_BAD_REQUEST, f"Unknown plugin {plugin} (available plugins: {self.plugins_list})"
         )
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_top(self, plugin: str, nb: int = 0):
         """Glances API RESTful implementation.
 
@@ -563,7 +563,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat ID
@@ -577,7 +577,6 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(statval)
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_history(self, plugin: str, nb: int = 0):
         """Glances API RESTful implementation.
 
@@ -590,7 +589,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat ID
@@ -600,7 +599,6 @@ class GlancesRestfulApi:
 
         return statval
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_limits(self, plugin: str):
         """Glances API RESTful implementation.
 
@@ -619,7 +617,6 @@ class GlancesRestfulApi:
 
         return GlancesJSONResponse(ret)
 
-    @weak_lru_cache(maxsize=1, ttl=1)
     def _api_views(self, plugin: str):
         """Glances API RESTful implementation.
 
@@ -652,7 +649,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat views
@@ -677,7 +674,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat views
@@ -702,7 +699,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat views
@@ -726,7 +723,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat views
@@ -751,7 +748,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value of the stat history
@@ -810,7 +807,7 @@ class GlancesRestfulApi:
         self._check_if_plugin_available(plugin)
 
         # Update the stat
-        self.__update_stats()
+        self.__update_stats(get_plugin_dependencies(plugin))
 
         try:
             # Get the RAW value
